==> jc-1.4.0.tar.gz: gnu/xml/xpath/Predicate.h <==
// class gnu.xml.xpath.Predicate

// class file dependencies
// @dep_class 22866b34eb0bc0fa gnu_xml_xpath_Predicate
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Test

#include "gnu/xml/xpath/Test.h"

#ifndef _JC_gnu_xml_xpath_Predicate_H_
#define _JC_gnu_xml_xpath_Predicate_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_gnu_xml_xpath_Test$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Predicate$sub_refs	_jc_gnu_xml_xpath_Predicate$sub_refs;
typedef struct _jc_gnu_xml_xpath_Predicate$sub_nonrefs	_jc_gnu_xml_xpath_Predicate$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Predicate$refs	_jc_gnu_xml_xpath_Predicate$refs;
typedef struct _jc_gnu_xml_xpath_Predicate$nonrefs	_jc_gnu_xml_xpath_Predicate$nonrefs;
typedef struct _jc_gnu_xml_xpath_Predicate$object	_jc_gnu_xml_xpath_Predicate$object;

typedef const struct _jc_gnu_xml_xpath_Predicate$vmethods	_jc_gnu_xml_xpath_Predicate$vmethods;
typedef const struct _jc_gnu_xml_xpath_Predicate$vtable	_jc_gnu_xml_xpath_Predicate$vtable;
typedef const struct _jc_gnu_xml_xpath_Predicate$vtype	_jc_gnu_xml_xpath_Predicate$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Predicate$method$_init$e760c49b15e85bcf(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_gnu_xml_xpath_Expr$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Test$object *_jc_gnu_xml_xpath_Predicate$method$clone$73a8d2a4d673dd95(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_gnu_xml_xpath_Predicate$method$matches$528a77e426fd27f8(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_object *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_Predicate$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Predicate$method_info$clone$73a8d2a4d673dd95;
extern _jc_method _jc_gnu_xml_xpath_Predicate$method_info$matches$528a77e426fd27f8;
extern _jc_method _jc_gnu_xml_xpath_Predicate$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Predicate$vmethods {
	struct _jc_gnu_xml_xpath_Test$object	*(*clone$73a8d2a4d673dd95)(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*matches$528a77e426fd27f8)(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_object *, jint, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_Predicate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Test$vmethods	gnu_xml_xpath_Test;
	_jc_gnu_xml_xpath_Predicate$vmethods	gnu_xml_xpath_Predicate;
};

// Vtype
struct _jc_gnu_xml_xpath_Predicate$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Predicate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Predicate$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*expr;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Predicate$refs {
    _jc_gnu_xml_xpath_Predicate$sub_refs	gnu_xml_xpath_Predicate;
    _jc_gnu_xml_xpath_Test$sub_refs	gnu_xml_xpath_Test;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Predicate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Predicate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Test$sub_nonrefs	gnu_xml_xpath_Test;
    _jc_gnu_xml_xpath_Predicate$sub_nonrefs	gnu_xml_xpath_Predicate;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Predicate$object {
	_jc_gnu_xml_xpath_Predicate$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Predicate$vtype	*vtype;
	_jc_gnu_xml_xpath_Predicate$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Predicate$vtype _jc_gnu_xml_xpath_Predicate$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Predicate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Predicate$class_object;

#endif	/* _JC_gnu_xml_xpath_Predicate_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/Predicate.h <==
// class gnu.xml.xpath.Predicate

// class file dependencies
// @dep_class 22866b34eb0bc0fa gnu_xml_xpath_Predicate
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Test

#include "gnu/xml/xpath/Test.h"

#ifndef _JC_gnu_xml_xpath_Predicate_H_
#define _JC_gnu_xml_xpath_Predicate_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_gnu_xml_xpath_Test$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Predicate$sub_refs	_jc_gnu_xml_xpath_Predicate$sub_refs;
typedef struct _jc_gnu_xml_xpath_Predicate$sub_nonrefs	_jc_gnu_xml_xpath_Predicate$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Predicate$refs	_jc_gnu_xml_xpath_Predicate$refs;
typedef struct _jc_gnu_xml_xpath_Predicate$nonrefs	_jc_gnu_xml_xpath_Predicate$nonrefs;
typedef struct _jc_gnu_xml_xpath_Predicate$object	_jc_gnu_xml_xpath_Predicate$object;

typedef const struct _jc_gnu_xml_xpath_Predicate$vmethods	_jc_gnu_xml_xpath_Predicate$vmethods;
typedef const struct _jc_gnu_xml_xpath_Predicate$vtable	_jc_gnu_xml_xpath_Predicate$vtable;
typedef const struct _jc_gnu_xml_xpath_Predicate$vtype	_jc_gnu_xml_xpath_Predicate$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Predicate$method$_init$e760c49b15e85bcf(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_gnu_xml_xpath_Expr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Test$object *_jc_gnu_xml_xpath_Predicate$method$clone$73a8d2a4d673dd95(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_Predicate$method$matches$528a77e426fd27f8(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_Predicate$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Predicate$method_info$clone$73a8d2a4d673dd95;
extern _jc_method _jc_gnu_xml_xpath_Predicate$method_info$matches$528a77e426fd27f8;
extern _jc_method _jc_gnu_xml_xpath_Predicate$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Predicate$vmethods {
	struct _jc_gnu_xml_xpath_Test$object	*(*clone$73a8d2a4d673dd95)(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*matches$528a77e426fd27f8)(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_Predicate$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_Predicate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Test$vmethods	gnu_xml_xpath_Test;
	_jc_gnu_xml_xpath_Predicate$vmethods	gnu_xml_xpath_Predicate;
};

// Vtype
struct _jc_gnu_xml_xpath_Predicate$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Predicate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Predicate$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*expr;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Predicate$refs {
    _jc_gnu_xml_xpath_Predicate$sub_refs	gnu_xml_xpath_Predicate;
    _jc_gnu_xml_xpath_Test$sub_refs	gnu_xml_xpath_Test;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Predicate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Predicate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Test$sub_nonrefs	gnu_xml_xpath_Test;
    _jc_gnu_xml_xpath_Predicate$sub_nonrefs	gnu_xml_xpath_Predicate;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Predicate$object {
	_jc_gnu_xml_xpath_Predicate$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Predicate$vtype	*vtype;
	_jc_gnu_xml_xpath_Predicate$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Predicate$vtype _jc_gnu_xml_xpath_Predicate$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Predicate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Predicate$class_object;

#endif	/* _JC_gnu_xml_xpath_Predicate_H_ */
